==> phpwiki_1.3.12p2.orig.tar.gz: phpwiki-1.3.12p2/locale/it/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%d best incoming links: "] =
   "%d migliori link in entrata: ";
$locale["%d best outgoing links: "] =
   "%d migliori link in uscita: ";
$locale["%d most popular nearby: "] =
   "%d pi popolari: ";
$locale["%s Kb (%s bytes)"] =
   "%s Kb (%s byte)";
$locale["%s at %s"] =
   "%s a %s";
$locale["%s bytes"] =
   "%s byte";
$locale["%s days"] =
   "%s giorni";
$locale["%s not found"] =
   "%s non trovato";
$locale["%s of this page"] =
   "%s di questa pagina";
$locale["%s on %s:"] =
   "%s a %s:";
$locale["%s: %s"] =
   "%s: %s";
$locale["%s: file not found"] =
   "%s: archivio non trovato";
$locale["%s: not defined"] =
   "%s: non definito";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] =
   "(Copia le tue modifiche nella clipboard. Potete provare a modificare un'altra pagina o registra il vostro testo in un editor di testo.)";
$locale["(diff)"] =
   "(diff)";
$locale[", Memory: %s"] =
   ", RAM: %s";
$locale["- saved to database as version %d"] =
   "- salvata a base di dati a versione %d";
$locale["- version %d saved to database as version %d"] =
   "- versione %d salvata a base di dati a versione %d";
$locale["... copied to %s"] =
   "... copia di %s";
$locale["... not copied to %s"] =
   "... nonc opia di %s";
$locale["... not found"] =
   "... non trovato";
$locale["1 day"] =
   "1 giorno";
$locale["<no matches>"] =
   "<nessun risultati>";
$locale["<none>"] =
   "<nessun>";
$locale["<unknown>"] =
   "<sconosciuto>";
$locale["AddCategory"] =
   "InsertoCategoria";
$locale["AddPlugin"] =
   "InsertoPlugin";
$locale["Authenticated as %s"] =
   "Authenticata a %s";
$locale["Author"] =
   "Autore";
$locale["Calendar"] =
   "Calendario";
$locale["CalendarList"] =
   "ListaCalendario";
$locale["CalendarListPlugin"] =
   "CalendarioListPlugin";
$locale["CalendarPlugin"] =
   "CalendarioPlugin";
$locale["Cancel"] =
   "Annulla";
$locale["Cancel rating"] =
   "Annulla";
$locale["CategoryGroup"] =
   "CategoriaGruppo";
$locale["CategoryPage"] =
   "CategoriaPagina";
$locale["Columns: %s."] =
   "Caratteri: %s.";
$locale["Comment"] =
   "Commentario";
$locale["Content"] =
   "Indice";
$locale["Contents"] =
   "Indice";
$locale["Convert"] =
   "Convertito";
$locale["Couldn't connect to %s"] =
   "Non riesco a stabilire una connessione col database: %s";
$locale["Create: %s"] =
   "Salvata: %s";
$locale["Deleted"] =
   "Rimossa";
$locale["Describe %s here."] =
   "Descrivi %s qui.";
$locale["Diff"] =
   "Diff";
$locale["Diff: %s"] =
   "Differenza di: %s";
$locale["Edit"] =
   "Modifica";
$locale["Edit %s"] =
   "Modifica %s";
$locale["Edit: %s"] =
   "Modifica: %s";
$locale["EditText"] =
   "ModificaIlTesto";
$locale["Edited by: %s"] =
   "Modifica: %s";
$locale["Fatal PhpWiki Error"] =
   "Errore Fatale Di PhpWiki";
$locale["FindPage"] =
   "TrovaPagina";
$locale["First"] =
   "Prima";
$locale["Full text search results for '%s'"] =
   "Risultati della ricerca su tutto il testo per '%s'";
$locale["FullTextSearch"] =
   "RicercaDelTesto";
$locale["Go"] =
   "Vai";
$locale["GoTo"] =
   "Vai";
$locale["GoodStyle"] =
   "BuonStile";
$locale["H"] =
   "A";
$locale["Height"] =
   "Altezza";
$locale["Home"] =
   "Principale";
$locale["HomePage"] =
   "PaginaPrincipale";
$locale["HomePageAlias"] =
   "PaginaPrincipaleAlias";
$locale["Include of '%s' failed."] =
   "Inserimento di '%s' fallito.";
$locale["IncludePage"] =
   "InserireLaPagina";
$locale["IncludePagePlugin"] =
   "InserireLaPaginaPlugin";
$locale["IncludePages"] =
   "InserirePaginas";
$locale["Included from %s"] =
   "Inserire dalla %s";
$locale["Included from %s:"] =
   "Inserire dalla %s:";
$locale["Insert"] =
   "Inserto";
$locale["Insert Categories (double-click)"] =
   "Inserto Categorias (doppio-scatto)";
$locale["Insert PageLink (double-click)"] =
   "Inserto Pagina (doppio-scatto)";
$locale["Insert Plugin (double-click)"] =
   "Inserto Plugin (doppio-scatto)";
$locale["Last"] =
   "Ultima";
$locale["Last Author"] =
   "Ultimo Autore";
$locale["Last Modified"] =
   "Ultima Modifica";
$locale["Last Summary"] =
   "Ultimo Commenti";
$locale["Last edited %s"] =
   "Ultima modifica %s";
$locale["Last edited on %s"] =
   "Ultima modifica su %s";
$locale["LdapSearch"] =
   "LdapRicerca";
$locale["LiveSearch"] =
   "RicercaLive";
$locale["Lock"] =
   "Bloccata";
$locale["Lock Page"] =
   "Blocca la Pagina";
$locale["Locked"] =
   "Bloccata";
$locale["MIME file %s"] =
   "MIME archivio %s";
$locale["ModeratedPage"] =
   "PaginaModerata";
$locale["Modern"] =
   "Moderno";
$locale["Modified"] =
   "Modifica";
$locale["MostPopular"] =
   "PiPopolari";
$locale["Name"] =
   "Nome";
$locale["New page"] =
   "Nuova pagina";
$locale["Newer page:"] =
   "Nuova pagina:";
$locale["Next"] =
   "Seguente";
$locale["None"] =
   "Nessuno";
$locale["Note:"] =
   "Nota:";
$locale["Optimizing database"] =
   "Base di dati d'ottimizzazione";
$locale["Other version"] =
   "Mostra il versione corrente";
$locale["Owner: %s"] =
   "Owner: %s";
$locale["Page %s not found."] =
   "%s: pagina non trovato.";
$locale["Page Locked"] =
   "Pagina Bloccata";
$locale["Page Name"] =
   "Nome Della Pagina";
$locale["Page now locked."] =
   "Pagina bloccata.";
$locale["Page now unlocked."] =
   "Pagina sbloccata.";
$locale["Page removed %s"] =
   "Pagina rimosso %s";
$locale["PhpWikiAdministration/Remove"] =
   "AmministrazioneDiPhpWiki/Rimuovi";
$locale["Plugin %s disabled."] =
   "Plugin '%s' inabiliti.";
$locale["Plugin %s failed."] =
   "Plugin '%s' fallito.";
$locale["Plugin %s: undefined"] =
   "Plugin '%s': non definito";
$locale["PreferencesInfo"] =
   "PreferenzeInfo";
$locale["PrevNext"] =
   "Seguente";
$locale["Previous"] =
   "Precedente";
$locale["Previous Author"] =
   "Precedente Author";
$locale["Previous Revision"] =
   "Precedente";
$locale["Printer"] =
   "Stampante";
$locale["RecentChanges"] =
   "CambiamentiRecenti";
$locale["Remove"] =
   "Rimuovi";
$locale["Remove Page"] =
   "Rimuovi la Pagina";
$locale["Remove this page"] =
   "Rimuovi la pagina";
$locale["Removed page '%s' successfully."] =
   "La pagina '%s'  stata rimossa correttamente.";
$locale["Save"] =
   "Registra";
$locale["Saved: %s"] =
   "Salvata: %s";
$locale["Search"] =
   "Ricerca";
$locale["See %s tips for editing."] =
   "Vedere %s consigli per le modifiche.";
$locale["Select"] =
   "Prescelto";
$locale["Show minor edits for:"] =
   "Mostrare le modifiche secondarie per:";
$locale["Signed as %s"] =
   "Salvata a %s";
$locale["Size"] =
   "Dimensione";
$locale["Size:"] =
   "Dimensione:";
$locale["Someone has edited the page!"] =
   "Qualcuno ha modificato la pagina!";
$locale["Sorry for the inconvenience."] =
   "Scusa per l'inconveniente.";
$locale["Sort by %s"] =
   "Sort di %s";
$locale["String \"%s\" not found."] =
   "\"%s\" non trovato.";
$locale["Summary"] =
   "Commenti";
$locale["Synopsis"] =
   "Sinossi";
$locale["TextFormattingRules"] =
   "RegoleDiFormattazioneDelTesto";
$locale["Thank you for editing %s."] =
   "Grazie per le modifiche! %s.";
$locale["Thanks for adding this translation!"] =
   "Grazie per la translatione!";
$locale["The %d most popular pages of this wiki:"] =
   "Le %d pagine pi popolari di questo wiki sono:";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Questa pagina  stata bloccata dall'amministratore e non pu essere modificata.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "Questa pagina  stata bloccata dall'amministratore in modo da i vostri cambiamenti non possono essere salvati.";
$locale["Time Zone"] =
   "Fuso Orario";
$locale["Title Search"] =
   "La ricerca su tutto il testo";
$locale["Title search results for '%s'"] =
   "Risultati della ricerca su tutto il testo per '%s'";
$locale["TitleSearch"] =
   "RicercaSuTutto";
$locale["Today"] =
   "Oggi";
$locale["Transcluded from %s"] =
   "Inserire dalla %s";
$locale["Unlock"] =
   "Sblocca";
$locale["Unlock Page"] =
   "Sblocca la Pagina";
$locale["UserPreferences"] =
   "Preferenze";
$locale["Version"] =
   "Versione";
$locale["Version %d"] =
   "Versione %d";
$locale["Version %s"] =
   "Versione %s";
$locale["Version %s, saved %s"] =
   "Versione %s, salvata %s";
$locale["Version %s, saved on %s"] =
   "Versione %s, salvata su %s";
$locale["Versions are identical"] =
   "Le versioni sono identiche";
$locale["View the current version"] =
   "Mostra il versione corrente";
$locale["W"] =
   "L";
$locale["Warning!"] =
   "Avvertimento!";
$locale["Warning:"] =
   "Avvertimento:";
$locale["Width"] =
   "Larghezza";
$locale["Wiki Name"] =
   "Wiki Nome";
$locale["Yes"] =
   "Si";
$locale["Your careful attention to detail is much appreciated."] =
   "La tua cura verso il dettaglio  molto apprezzata.";
$locale["Your home page is locked so your preferences cannot not be saved."] =
   "Questa pagina  stata bloccata dall'amministratore in modo da i vostri cambiamenti non possono essere salvati.";
$locale["Your version"] =
   "versione corrente";
$locale["by %s"] =
   "di %s";
$locale["current version"] =
   "versione corrente";
$locale["days"] =
   "giorni";
$locale["diff"] =
   "diff";
$locale["from %s"] =
   "dalla %s";
$locale["locked"] =
   "bloccata";
$locale["name"] =
   "Nome";
$locale["plain file %s"] =
   "archivio del testo %s";
$locale["saved as "] =
   "salvata a ";
$locale["saved as %s"] =
   "salvata a %s";
$locale["today"] =
   "oggi";
$locale["version %d"] =
   "versione %d";
$locale["version %s"] =
   "versione %s";
$locale["version <em>%s</em>"] =
   "versione <em>%s</em>";
$locale["yesterday"] =
   "ieri";

?>

==> phpwiki_1.3.14.orig.tar.gz: phpwiki-1.3.14/locale/it/LC_MESSAGES/phpwiki.php <==
<?php

$locale[" ... first %d bytes"] =
   " ... i primi %d byte";
$locale[" Sorry, cannot merge."] =
   " Spiacente, non pu fondersi.";
$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%d best incoming links: "] =
   "%d migliori link in entrata: ";
$locale["%d best outgoing links: "] =
   "%d migliori link in uscita: ";
$locale["%d most popular nearby: "] =
   "%d pi popolari: ";
$locale["%s Kb (%s bytes)"] =
   "%s Kb (%s byte)";
$locale["%s at %s"] =
   "%s a %s";
$locale["%s bytes"] =
   "%s byte";
$locale["%s days"] =
   "%s giorni";
$locale["%s not defined"] =
   "%s: non definito";
$locale["%s not found"] =
   "%s non trovato";
$locale["%s of this page"] =
   "%s di questa pagina";
$locale["%s on %s:"] =
   "%s a %s:";
$locale["%s: %s"] =
   "%s: %s";
$locale["%s: file not found"] =
   "%s: file non trovato";
$locale["%s: not defined"] =
   "%s: non definito";
$locale["'%s': corrupt file"] =
   "'%s': file corrotto";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] =
   "(Copia le tue modifiche nella clipboard. Potete provare a modificare un'altra pagina o registra il vostro testo in un editor di testo.)";
$locale["(diff)"] =
   "(diff)";
$locale[", Memory: %s"] =
   ", RAM: %s";
$locale["- saved to database as version %d"] =
   "- salvata a base di dati a versione %d";
$locale["- version %d saved to database as version %d"] =
   "- versione %d salvata a base di dati a versione %d";
$locale["... copied to %s"] =
   "... copia di %s";
$locale["... not copied to %s"] =
   "... nonc opia di %s";
$locale["... not found"] =
   "... non trovato";
$locale["1 day"] =
   "1 giorno";
$locale["<no matches>"] =
   "<nessuna corrispondenza>";
$locale["<none>"] =
   "<nessun>";
$locale["<unknown>"] =
   "<sconosciuto>";
$locale["AddCategory"] =
   "InsertoCategoria";
$locale["AddPlugin"] =
   "InsertoPlugin";
$locale["AddTemplate"] =
   "AggiungaLaMascherina";
$locale["Administrators"] =
   "Coordinatori";
$locale["Anonymous Users"] =
   "Utenti Anonimi";
$locale["Authenticated Users"] =
   "Utenti Autenticati";
$locale["Authenticated as %s"] =
   "Utente corrente: %s";
$locale["Author"] =
   "Autore";
$locale["Author will be logged as %s."] =
   "L'autore sar annotato come %s.";
$locale["Bogo Users"] =
   "Utenti Bogo";
$locale["Calendar"] =
   "Calendario";
$locale["CalendarList"] =
   "ListaCalendario";
$locale["CalendarListPlugin"] =
   "CalendarioListPlugin";
$locale["CalendarPlugin"] =
   "CalendarioPlugin";
$locale["Cancel"] =
   "Annulla";
$locale["Cancel rating"] =
   "Annulla";
$locale["Category"] =
   "Categoria";
$locale["CategoryGroup"] =
   "CategoriaGruppo";
$locale["CategoryPage"] =
   "CategoriaPagina";
$locale["Columns: %s."] =
   "Caratteri: %s.";
$locale["Comment"] =
   "Commentario";
$locale["Conflicting Edits!"] =
   "Il Conflitto Pubblica!";
$locale["Content"] =
   "Indice";
$locale["Contents"] =
   "Indice";
$locale["Convert"] =
   "Convertito";
$locale["Couldn't connect to %s"] =
   "Non riesco a stabilire una connessione col database: %s";
$locale["Create: %s"] =
   "Salvata: %s";
$locale["Date Format"] =
   "Formato della Data";
$locale["DebugInfo"] =
   "InfoDebug";
$locale["Deleted"] =
   "Rimossa";
$locale["Describe %s here."] =
   "Inserire qui il testo della pagina %s.";
$locale["Diff"] =
   "Differenze";
$locale["Diff: %s"] =
   "Differenza di: %s";
$locale["Differences between %s and %s of %s."] =
   "Differenze tra %s e %s di %s.";
$locale["Edit"] =
   "Modifica";
$locale["Edit %s"] =
   "Modifica %s";
$locale["Edit: %s"] =
   "Modifica: %s";
$locale["EditText"] =
   "ModificaIlTesto";
$locale["Edited by: %s"] =
   "Modifica: %s";
$locale["Every"] =
   "Ogni";
$locale["External Links"] =
   "Collegamenti Esterni";
$locale["Fatal PhpWiki Error"] =
   "Errore Fatale Di PhpWiki";
$locale["FindPage"] =
   "TrovaPagina";
$locale["First"] =
   "Prima";
$locale["Full text search results for '%s'"] =
   "Risultati della ricerca su tutto il testo per '%s'";
$locale["FullTextSearch"] =
   "RicercaDelTesto";
$locale["Go"] =
   "Vai";
$locale["GoTo"] =
   "Vai";
$locale["H"] =
   "A";
$locale["HasHomePage"] =
   "HaHomePage";
$locale["Height"] =
   "Altezza";
$locale["Home"] =
   "Principale";
$locale["HomePage"] =
   "PaginaPrincipale";
$locale["HomePageAlias"] =
   "AliasPaginaPrincipale";
$locale["In the time since you started editing this page, another user has saved a new version of it."] =
   "Nel tempo da quando avete cominciato pubblicare questa pagina, un altro utente ha conservato una nuova versione di esso.";
$locale["Include of '%s' failed."] =
   "Inserimento di '%s' fallito.";
$locale["IncludePage"] =
   "InserireLaPagina";
$locale["IncludePagePlugin"] =
   "InserireLaPaginaPlugin";
$locale["IncludePages"] =
   "InserirePaginas";
$locale["Included from %s"] =
   "Inserire dalla %s";
$locale["Included from %s:"] =
   "Inserire dalla %s:";
$locale["Insert"] =
   "Inserto";
$locale["Insert Categories (double-click)"] =
   "Inserimento Categorie (doppio-click)";
$locale["Insert PageLink (double-click)"] =
   "Inserto Pagina (doppio-scatto)";
$locale["Insert Plugin (double-click)"] =
   "Inserto Plugin (doppio-scatto)";
$locale["Insert Template (double-click)"] =
   "Inserto Mascherina (doppio-scatto)";
$locale["Insufficient permissions."] =
   "Permessi insufficienti.";
$locale["Invalid password or userid."] =
   "Password o nome utente errati.";
$locale["JabberPresence"] =
   "JabberPresenca";
$locale["Last"] =
   "Ultima";
$locale["Last Author"] =
   "Ultimo Autore";
$locale["Last Modified"] =
   "Ultima Modifica";
$locale["Last Summary"] =
   "Ultimo Commenti";
$locale["Last edited %s"] =
   "Ultima modifica %s";
$locale["Last edited on %s"] =
   "Ultima modifica %s";
$locale["LdapSearch"] =
   "LdapRicerca";
$locale["LikePages"] =
   "PagineSimili";
$locale["LiveSearch"] =
   "RicercaLive";
$locale["Lock"] =
   "Bloccata";
$locale["Lock Page"] =
   "Blocca la Pagina";
$locale["Locked"] =
   "Bloccata";
$locale["Locking pages"] =
   "Blocca la Pagina";
$locale["MIME file %s"] =
   "MIME archivio %s";
$locale["Merge Edit"] =
   "La Fusione Pubblica";
$locale["Merge and Edit: %s"] =
   "Fondasi e pubblichi: %s";
$locale["ModeratedPage"] =
   "PaginaModerata";
$locale["Modern"] =
   "Moderno";
$locale["Modified"] =
   "Modifica";
$locale["MostPopular"] =
   "PiPopolari";
$locale["Name"] =
   "Nome";
$locale["New page"] =
   "Nuova pagina";
$locale["Newer page:"] =
   "Nuova pagina:";
$locale["Next"] =
   "Seguente";
$locale["None"] =
   "Nessuno";
$locale["Note:"] =
   "Nota:";
$locale["Optimizing database"] =
   "Base di dati d'ottimizzazione";
$locale["Other diffs:"] =
   "Altre differenze:";
$locale["Other version"] =
   "Altra versione";
$locale["Overwrite All"] =
   "Scriva sopra Tutti";
$locale["Owner"] =
   "Proprietario";
$locale["Owner: %s"] =
   "Owner: %s";
$locale["Page %s not found."] =
   "%s: pagina non trovato.";
$locale["Page Locked"] =
   "Pagina Bloccata";
$locale["Page Name"] =
   "Nome della Pagina";
$locale["Page change"] =
   "Cambiamento della pagina";
$locale["Page now locked."] =
   "Pagina bloccata.";
$locale["Page now unlocked."] =
   "Pagina sbloccata.";
$locale["Page removed %s"] =
   "Pagina rimosso %s";
$locale["Page rename %s to %s"] =
   "La pagina cambia titolo %s a %s";
$locale["PageChange Notification Error: Couldn't send %s to %s"] =
   "Errore Di Notifica Del Cambiamento Della Pagina:  Non ha potuto trasmettere %s a %s";
$locale["PageChange Notification of %s sent to %s"] =
   "Pagini la notifica del cambiamento di %s trasmesso a %s";
$locale["PageHistory"] =
   "StoricoPagina";
$locale["PageInfo"] =
   "InfoPagina";
$locale["PhpWikiAdministration/Markup"] =
   "AmministrazioneDiPhpWiki/Disposizione";
$locale["PhpWikiAdministration/Remove"] =
   "AmministrazioneDiPhpWiki/Rimuovi";
$locale["Please check it through before saving."] =
   "Si prega di controllarla nel dettaglio prima di salvare.";
$locale["Plugin %s disabled."] =
   "Plugin '%s' inabiliti.";
$locale["Plugin %s failed."] =
   "Plugin '%s' fallito.";
$locale["Plugin %s: undefined"] =
   "Plugin '%s': non definito";
$locale["PreferenceApp"] =
   "PreferenzeApp";
$locale["Preferences"] =
   "Preferenze";
$locale["PreferencesInfo"] =
   "PreferenzeInfo";
$locale["PrevNext"] =
   "Seguente";
$locale["Preview"] =
   "Anteprima";
$locale["Previous"] =
   "Precedente";
$locale["Previous Author"] =
   "Precedente Author";
$locale["Previous Revision"] =
   "Precedente";
$locale["Printer"] =
   "Stampante";
$locale["PurgeHtmlCache"] =
   "RimuoviDallaCacheHtml";
$locale["RecentChanges"] =
   "ModificheRecenti";
$locale["Related Changes"] =
   "Modifiche Correlate";
$locale["Related Links"] =
   "Collegamenti Relativi";
$locale["Remove"] =
   "Cancella";
$locale["Remove Page"] =
   "Cancella la Pagina";
$locale["Remove this page"] =
   "Rimuovi la pagina";
$locale["Removed by: %s"] =
   "Rimosso vicino: %s";
$locale["Removed page '%s' successfully."] =
   "La pagina '%s'  stata rimossa correttamente.";
$locale["Removing pages"] =
   "Rimuovi la pagina";
$locale["Restore Anyway"] =
   "Restore Comunque";
$locale["Revert"] =
   "Ritorni";
$locale["Save"] =
   "Registra";
$locale["Saved: %s"] =
   "Salvata: %s";
$locale["Search"] =
   "Ricerca";
$locale["See %s tips for editing."] =
   "Vedere %s consigli per le modifiche.";
$locale["Select"] =
   "Prescelto";
$locale["Show minor edits for:"] =
   "Mostrare le modifiche secondarie per:";
$locale["Sign In"] =
   "Login";
$locale["Sign Out"] =
   "Logout";
$locale["Sign in as:"] =
   "Username di login:";
$locale["Signed Users"] =
   "Utenti Firmati";
$locale["Size"] =
   "Dimensione";
$locale["Size:"] =
   "Dimensione:";
$locale["Some of the changes could not automatically be combined.  Please look for sections beginning with '%s', and ending with '%s'.  You will need to edit those sections by hand before you click Save."] =
   "Alcuni dei cambiamenti non hanno potuto essere uniti automaticamente. Cerchi prego le sezioni che cominciano con '%s 'e concludentesi con '%s '. Dovrete pubblicare a mano quelle sezioni prima che vi scattiate risparmi.";
$locale["Someone has edited the page!"] =
   "Qualcuno ha modificato la pagina!";
$locale["Sorry for the inconvenience."] =
   "Scusa per l'inconveniente.";
$locale["Sort by %s"] =
   "Ordina per %s";
$locale["String \"%s\" not found."] =
   "\"%s\" non trovato.";
$locale["Summary"] =
   "Commenti";
$locale["Synopsis"] =
   "Sommario";
$locale["Thank you for editing %s."] =
   "La pagina %s <E8> stata modificata.";
$locale["Thanks for adding this translation!"] =
   "Grazie per la translatione!";
$locale["The %d most popular pages of this wiki:"] =
   "Le %d pagine pi popolari di questo wiki sono:";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Questa pagina  stata bloccata dall'amministratore e non pu essere modificata.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "Spiacente, ma questa pagina  stata bloccata dall'amministratore,quindi le tue modifiche non possono essere salvate.";
$locale["Time Zone"] =
   "Fuso Orario";
$locale["Title Search"] =
   "Ricerca per Titolo";
$locale["Title search results for '%s'"] =
   "Risultati della ricerca su tutto il testo per '%s'";
$locale["TitleSearch"] =
   "RicercaPerTitolo";
$locale["Today"] =
   "Oggi";
$locale["Transcluded from %s"] =
   "Inserire dalla %s";
$locale["Unlock"] =
   "Sblocca";
$locale["Unlock Page"] =
   "Sblocca la Pagina";
$locale["Unlocking pages"] =
   "Sblocca la Pagina";
$locale["UserPreferences"] =
   "Preferenze";
$locale["Version"] =
   "Versione";
$locale["Version %d"] =
   "Versione %d";
$locale["Version %s"] =
   "Versione %s";
$locale["Version %s, saved %s"] =
   "Versione %s, salvata %s";
$locale["Version %s, saved on %s"] =
   "Versione %s, salvata su %s";
$locale["Versions are identical"] =
   "Le versioni sono identiche";
$locale["View Source: %s"] =
   "Vedi il Sorgente: %s";
$locale["View the current version"] =
   "Mostra il versione corrente";
$locale["W"] =
   "L";
$locale["Warning:"] =
   "Avvertimento:";
$locale["Width"] =
   "Larghezza";
$locale["Wiki Name"] =
   "Wiki Nome";
$locale["WikiAdminMarkup"] =
   "WikiAmministrazioneDisposizione";
$locale["Yes"] =
   "Si";
$locale["You are signed in as %s"] =
   "Utente corrente: %s";
$locale["Your careful attention to detail is much appreciated."] =
   "Si prega di controllare che le modifiche siano quelle volute. Grazie.";
$locale["Your changes can not be saved as they are, since doing so would overwrite the other author's changes. So, your changes and those of the other author have been combined. The result is shown below."] =
   "I vostri cambiamenti non possono essere conservati mentre sono, dal fare in modo da scriverebbero sopra i cambiamenti dell'altro autore. Cos, i vostri cambiamenti e quelli dell'altro autore sono stati uniti. Il risultato  indicato sotto.";
$locale["Your home page is locked so your preferences cannot not be saved."] =
   "Questa pagina  stata bloccata dall'amministratore in modo da i vostri cambiamenti non possono essere salvati.";
$locale["Your version"] =
   "La versione corrente";
$locale["authenticated"] =
   "autenticato";
$locale["by %s"] =
   "di %s";
$locale["current version"] =
   "versione corrente";
$locale["days"] =
   "giorni";
$locale["diff"] =
   "diff";
$locale["from %s"] =
   "dalla %s";
$locale["locked"] =
   "bloccata";
$locale["name"] =
   "Nome";
$locale["not authenticated"] =
   "non autenticato";
$locale["plain file %s"] =
   "archivio del testo %s";
$locale["saved as "] =
   "salvata a ";
$locale["saved as %s"] =
   "salvata a %s";
$locale["today"] =
   "oggi";
$locale["version %d"] =
   "versione %d";
$locale["version %s"] =
   "versione %s";
$locale["version <em>%s</em>"] =
   "versione <em>%s</em>";
$locale["yesterday"] =
   "ieri";

?>
